//--------------------------------------------------------------------------
//--------------------------------------------------------------------------
#include <msp430.h>                             //(1) include msp430 constants & declarations

unsigned int wait_time = 500;                   //(2.1) define wait time between number changes
short v_act = 0x80;                             //(2.2) help variable for button
int adc10_read;

void wait001(unsigned long int i_wt);           //(3) there will be "wait001" function
void wm_01(void);                               //(4.1) character set: number 1
void wm_02(void);                               //(4.2) character set: number 2
void wm_03(void);                               //(4.3) character set: number 3
void wm_04(void);                               //(4.4) character set: number 4
void wm_05(void);                               //(4.5) character set: number 5
void wm_06(void);                               //(4.6) character set: number 6
void wm_x2(void);                               //(4.7) character set: number "strange 2"
void wm_space(void);                            //(4.8) character set: all off
void show_test(void);                           //(4.9) LED test for start-up
void read_adc10(void);
//--------------------------------------------------------------------------
//--------------------------------------------------------------------------
int main(void)                                  //(5) main function starts here
{
    WDTCTL = WDTPW | WDTHOLD;                   //(6) Stop watchdog timer
    P1DIR = 0b11111110;                         //(7) set-up I/O direction for P1
    P2SEL = 0x00;                               //(8.1) P2.7 setup / step 1
    P2DIR = 0b00000000;                         //(8.2) P2.7 setup / step 2
    P2REN = 0b11000000;                         //(8.3) enable resistor on P2.7
    P2OUT = 0b11000000;                         //(8.4) set up pull-up functionality for P2.7

    show_test();                                //(9) execute the LED test
    wm_x2();                                    //(10) show "strange 2"

    ADC10CTL1 = 0b0000000000000000;        //(13) set-up ADC10CTL1

    for(;;)                                     //(11) endless loop
    {
     read_adc10();
     while((P2IN & BIT7) != v_act)              //(12) inner loop - when button is pressed
      {
         if ((P2IN & BIT7) != v_act) wm_01();   //(13.1a) change to 1 - if the button is still pressed
         wait001(wait_time);                    //(13.1b) wait a bit to make the LEDs flashing
         if ((P2IN & BIT7) != v_act) wm_02();   //(13.2a) change to 2 - if the button is still pressed
         wait001(wait_time);                    //(13.2b) wait a bit to make the LEDs flashing
         if ((P2IN & BIT7) != v_act) wm_03();   //(13.3a) change to 3 - if the button is still pressed
         wait001(wait_time);                    //(13.3b) wait a bit to make the LEDs flashing
         if ((P2IN & BIT7) != v_act) wm_04();   //(13.4a) change to 4 - if the button is still pressed
         wait001(wait_time);                    //(13.4b) wait a bit to make the LEDs flashing
         if ((P2IN & BIT7) != v_act) wm_05();   //(13.5a) change to 5 - if the button is still pressed
         wait001(wait_time);                    //(13.5b) wait a bit to make the LEDs flashing
         if ((P2IN & BIT7) != v_act) wm_06();   //(13.6a) change to 6 - if the button is still pressed
         wait001(wait_time);                    //(13.6b) wait a bit to make the LEDs flashing
      }
    }
}
//--------------------------------------------------------------------------
//--------------------------------------------------------------------------
void show_test(void)                            //(T-1) LED test for start-up
{
    wm_space();                                 //(T-2) clear the display
    P1OUT = 0b10000001;                         //(T-3) switch on the P1.7 LED
    wait001(20000);                             //(T-4) wait a while
    P1OUT = 0b11000001;                         //(T-5) switch on the P1.6 LED
    wait001(20000);                             //(T-6) wait a while
    P1OUT = 0b11100001;                         //(T-7) switch on the P1.5 LED
    wait001(20000);                             //(T-8) wait a while
    P1OUT = 0b11110001;                         //(T-9) switch on the P1.4 LED
    wait001(20000);                             //(T-10) wait a while
    P1OUT = 0b11111001;                         //(T-11) switch on the P1.3 LED
    wait001(20000);                             //(T-12) wait a while
    P1OUT = 0b11111101;                         //(T-13) switch on the P1.2 LED
    wait001(20000);                             //(T-14) wait a while
    P1OUT = 0b11111111;                         //(T-15) switch on the P1.1 LED
    wait001(20000);                             //(T-16) wait a while
}
//--------------------------------------------------------------------------
//--------------------------------------------------------------------------
void wm_space(void)                             //(WM-S) switch off all LEDs
{
    P1OUT = 0x01;
}
//--------------------------------------------------------------------------
void wm_01(void)                                //(WM-1) show 1
{
    P1OUT = 0b00000011;
}
//--------------------------------------------------------------------------
void wm_02(void)                                //(WM-2) show 2
{
    P1OUT = 0b00110001;
}
//--------------------------------------------------------------------------
void wm_03(void)                                //(WM-3) show 3
{
    P1OUT = 0b00110011;
}
//--------------------------------------------------------------------------
void wm_04(void)                                //(WM-4) show 4
{
    P1OUT = 0b10110101;
}
//--------------------------------------------------------------------------
void wm_05(void)                                //(WM-5) show 5
{
    P1OUT = 0b10110111;
}
//--------------------------------------------------------------------------
void wm_06(void)                                //(WM-6) show 6
{
    P1OUT = 0b11111101;
}

//--------------------------------------------------------------------------
void wm_x2(void)                                //(WM-2x) show strange 2
{
    P1OUT = 0b01001001;
}
//--------------------------------------------------------------------------
//--------------------------------------------------------------------------
void wait001(unsigned long int i_wt)            //(D-1) delay routine
{
    volatile unsigned long int i;               //(D-2) volatile to prevent optimisation
    i = i_wt;                                   //(D-3) SW delay
    do i--;                                     //(D-4) delay loop
    while(i != 0);                              //(D-5) delay loop
    read_adc10();
}
//--------------------------------------------------------------------------
//--------------------------------------------------------------------------
void read_adc10(void)
{
    adc10_read = ADC10MEM;                 //(16) get the result from ADC10MEM register
    ADC10CTL0 = 0b0001100001111011;        //(14) set up ADC10CTL0 and start conversion

    wait_time = 50 + adc10_read * 20;

    if (adc10_read > 1020)
        {
            v_act = 0;
            wait_time = 20000;
        }
    else v_act = 0x80;
}
// ---------------------------------------------------------------------------------------
// ---------------------------------------------------------------------------------------
